# WATI API client library

[![license](https://img.shields.io/badge/license-Apache%20v2.0-blue.svg)](LICENSE) [![PyPI version](https://badge.fury.io/py/wati_api.svg)](https://badge.fury.io/py/wati_api)

## Installation

Install the client:

```bash
# Clone the source code
git clone https://github.com/ClareAI/wati_python
pip install -e .
```

This package can be found on [PyPI](https://pypi.python.org/pypi/wati_api).

```bash
pip install wati_api
```

## Examples

The example can be found [here](./examples/).

- Create a copy of the environment variables example. Then adjust it:

```bash
cp .env.example .env
```

- Source the .env file:

```bash
source .env
```

- Run the example:

```bash
python examples/main.py
```
